A Statistical Model for Multilingual Entity Detection and Tracking - ACL Anthology
Description: R. Florian, H. Hassan, A. Ittycheriah, H. Jing, N. Kambhatla, X. Luo, N. Nicolov, S. Roukos. Proceedings of the Human Language Technology Conference of the North American Chapter of the Association for Computational Linguistics: HLT-NAACL 2004. 2004.

## A Statistical Model for Multilingual Entity Detection and Tracking

R. Florian, H. Hassan, A. Ittycheriah, H. Jing, N. Kambhatla, X. Luo, N. Nicolov, S. Roukos

Anthology ID:
  N04-1001
Volume:
  Proceedings of the Human Language Technology Conference of the North American Chapter of the Association for Computational Linguistics: HLT-NAACL 2004
Month:
  May 2 - May 7
Year:
  2004
Address:
  Boston, Massachusetts, USA
Venue:
  NAACL
SIG:
Publisher:
  Association for Computational Linguistics
Note:
Pages:
  1–8
Language:
URL:
  https://aclanthology.org/N04-1001
DOI:
Bibkey:
Cite (ACL):
  R. Florian, H. Hassan, A. Ittycheriah, H. Jing, N. Kambhatla, X. Luo, N. Nicolov, and S. Roukos. 2004. A Statistical Model for Multilingual Entity Detection and Tracking. In Proceedings of the Human Language Technology Conference of the North American Chapter of the Association for Computational Linguistics: HLT-NAACL 2004, pages 1–8, Boston, Massachusetts, USA. Association for Computational Linguistics.
Cite (Informal):
  A Statistical Model for Multilingual Entity Detection and Tracking (Florian et al., NAACL 2004)
Copy Citation:
PDF:
  https://aclanthology.org/N04-1001.pdf

PDF Cite Search

##### Export citation

    @inproceedings{florian-etal-2004-statistical,
        title = "A Statistical Model for Multilingual Entity Detection and Tracking",
        author = "Florian, R.  and
          Hassan, H.  and
          Ittycheriah, A.  and
          Jing, H.  and
          Kambhatla, N.  and
          Luo, X.  and
          Nicolov, N.  and
          Roukos, S.",
        booktitle = "Proceedings of the Human Language Technology Conference of the North {A}merican Chapter of the Association for Computational Linguistics: {HLT}-{NAACL} 2004",
        month = may # " 2 - " # may # " 7",
        year = "2004",
        address = "Boston, Massachusetts, USA",
        publisher = "Association for Computational Linguistics",
        url = "https://aclanthology.org/N04-1001",
        pages = "1--8",
    }

    ﻿<?xml version="1.0" encoding="UTF-8"?>
    <modsCollection xmlns="http://www.loc.gov/mods/v3">
    <mods ID="florian-etal-2004-statistical">
        <titleInfo>
            <title>A Statistical Model for Multilingual Entity Detection and Tracking</title>
        </titleInfo>
        <name type="personal">
            <namePart type="given">R</namePart>
            <namePart type="family">Florian</namePart>
            <role>
                <roleTerm authority="marcrelator" type="text">author</roleTerm>
            </role>
        </name>
        <name type="personal">
            <namePart type="given">H</namePart>
            <namePart type="family">Hassan</namePart>
            <role>
                <roleTerm authority="marcrelator" type="text">author</roleTerm>
            </role>
        </name>
        <name type="personal">
            <namePart type="given">A</namePart>
            <namePart type="family">Ittycheriah</namePart>
            <role>
                <roleTerm authority="marcrelator" type="text">author</roleTerm>
            </role>
        </name>
        <name type="personal">
            <namePart type="given">H</namePart>
            <namePart type="family">Jing</namePart>
            <role>
                <roleTerm authority="marcrelator" type="text">author</roleTerm>
            </role>
        </name>
        <name type="personal">
            <namePart type="given">N</namePart>
            <namePart type="family">Kambhatla</namePart>
            <role>
                <roleTerm authority="marcrelator" type="text">author</roleTerm>
            </role>
        </name>
        <name type="personal">
            <namePart type="given">X</namePart>
            <namePart type="family">Luo</namePart>
            <role>
                <roleTerm authority="marcrelator" type="text">author</roleTerm>
            </role>
        </name>
        <name type="personal">
            <namePart type="given">N</namePart>
            <namePart type="family">Nicolov</namePart>
            <role>
                <roleTerm authority="marcrelator" type="text">author</roleTerm>
            </role>
        </name>
        <name type="personal">
            <namePart type="given">S</namePart>
            <namePart type="family">Roukos</namePart>
            <role>
                <roleTerm authority="marcrelator" type="text">author</roleTerm>
            </role>
        </name>
        <originInfo>
            <dateIssued>2004-may 2 - may 7</dateIssued>
        </originInfo>
        <typeOfResource>text</typeOfResource>
        <relatedItem type="host">
            <titleInfo>
                <title>Proceedings of the Human Language Technology Conference of the North American Chapter of the Association for Computational Linguistics: HLT-NAACL 2004</title>
            </titleInfo>
            <originInfo>
                <publisher>Association for Computational Linguistics</publisher>
                <place>
                    <placeTerm type="text">Boston, Massachusetts, USA</placeTerm>
                </place>
            </originInfo>
            <genre authority="marcgt">conference publication</genre>
        </relatedItem>
        <identifier type="citekey">florian-etal-2004-statistical</identifier>
        <location>
            <url>https://aclanthology.org/N04-1001</url>
        </location>
        <part>
            <date>2004-may 2 - may 7</date>
            <extent unit="page">
                <start>1</start>
                <end>8</end>
            </extent>
        </part>
    </mods>
    </modsCollection>

    ﻿%0 Conference Proceedings
    %T A Statistical Model for Multilingual Entity Detection and Tracking
    %A Florian, R.
    %A Hassan, H.
    %A Ittycheriah, A.
    %A Jing, H.
    %A Kambhatla, N.
    %A Luo, X.
    %A Nicolov, N.
    %A Roukos, S.
    %S Proceedings of the Human Language Technology Conference of the North American Chapter of the Association for Computational Linguistics: HLT-NAACL 2004
    %D 2004
    %8 may 2  may 7
    %I Association for Computational Linguistics
    %C Boston, Massachusetts, USA
    %F florian-etal-2004-statistical
    %U https://aclanthology.org/N04-1001
    %P 1-8

##### Markdown (Informal)

[A Statistical Model for Multilingual Entity Detection and Tracking](https://aclanthology.org/N04-1001) (Florian et al., NAACL 2004)

- A Statistical Model for Multilingual Entity Detection and Tracking (Florian et al., NAACL 2004)

##### ACL

- R. Florian, H. Hassan, A. Ittycheriah, H. Jing, N. Kambhatla, X. Luo, N. Nicolov, and S. Roukos. 2004. A Statistical Model for Multilingual Entity Detection and Tracking. In Proceedings of the Human Language Technology Conference of the North American Chapter of the Association for Computational Linguistics: HLT-NAACL 2004, pages 1–8, Boston, Massachusetts, USA. Association for Computational Linguistics.